Fix more typos, primarily in the code
authorPavel Roskin <proski@gnu.org>
Mon, 10 Jul 2006 05:50:18 +0000 (01:50 -0400)
committerJunio C Hamano <junkio@cox.net>
Mon, 10 Jul 2006 07:36:44 +0000 (00:36 -0700)
The only visible change is that git-blame doesn't understand
"--compability" anymore, but it does accept "--compatibility" instead,
which is already documented.

Signed-off-by: Pavel Roskin <proski@gnu.org>
Signed-off-by: Junio C Hamano <junkio@cox.net>
34 files changed:
Documentation/git-name-rev.txt
blame.c
builtin-apply.c
builtin-diff.c
builtin-grep.c
builtin-help.c
builtin-push.c
builtin-rm.c
combine-diff.c
compat/subprocess.py
contrib/colordiff/colordiff.perl
diff-delta.c
fetch-clone.c
git-am.sh
git-applypatch.sh
git-archimport.perl
git-commit.sh
git-cvsexportcommit.perl
git-instaweb.sh
git-merge-one-file.sh
git-merge-recursive.py
git-push.sh
git-quiltimport.sh
git-send-email.perl
git-svn.perl
name-rev.c
pack-objects.c
ppc/sha1ppc.S
sha1_file.c
t/t5700-clone-reference.sh
t/t5710-info-alternate.sh
t/t6002-rev-list-bisect.sh
t/t6021-merge-criss-cross.sh
xdiff/xdiffi.c
index 39a1434a0e6be3c07852dc0919536bc63551a3dd..43f8c2593dcc010b97b24cc8f5ca1caada7bef3b 100644 (file)
@@ -26,7 +26,7 @@ OPTIONS
        List all commits reachable from all refs
 
 --stdin::
-       Read from stdin, append "(<rev_name>)" to all sha1's of name'able
+       Read from stdin, append "(<rev_name>)" to all sha1's of nameable
        commits, and pass to stdout
 
 EXAMPLE
diff --git a/blame.c b/blame.c
index c86e2fd4b31fc75adf1c315fda166aabc38f0f43..0a06026168458de494f1cd089ea58470af4f3e56 100644 (file)
--- a/blame.c
+++ b/blame.c
 #define DEBUG 0
 
 static const char blame_usage[] = "[-c] [-l] [-t] [-S <revs-file>] [--] file [commit]\n"
-       "  -c, --compability Use the same output mode as git-annotate (Default: off)\n"
-       "  -l, --long        Show long commit SHA1 (Default: off)\n"
-       "  -t, --time        Show raw timestamp (Default: off)\n"
-       "  -S, --revs-file   Use revisions from revs-file instead of calling git-rev-list\n"
-       "  -h, --help        This message";
+       "  -c, --compatibility Use the same output mode as git-annotate (Default: off)\n"
+       "  -l, --long          Show long commit SHA1 (Default: off)\n"
+       "  -t, --time          Show raw timestamp (Default: off)\n"
+       "  -S, --revs-file     Use revisions from revs-file instead of calling git-rev-list\n"
+       "  -h, --help          This message";
 
 static struct commit **blame_lines;
 static int num_blame_lines;
@@ -747,7 +747,7 @@ int main(int argc, const char **argv)
        const char *filename = NULL, *commit = NULL;
        char filename_buf[256];
        int sha1_len = 8;
-       int compability = 0;
+       int compatibility = 0;
        int show_raw_time = 0;
        int options = 1;
        struct commit* start_commit;
@@ -774,8 +774,8 @@ int main(int argc, const char **argv)
                                sha1_len = 40;
                                continue;
                        } else if(!strcmp(argv[i], "-c") ||
-                                 !strcmp(argv[i], "--compability")) {
-                               compability = 1;
+                                 !strcmp(argv[i], "--compatibility")) {
+                               compatibility = 1;
                                continue;
                        } else if(!strcmp(argv[i], "-t") ||
                                  !strcmp(argv[i], "--time")) {
@@ -784,7 +784,7 @@ int main(int argc, const char **argv)
                        } else if(!strcmp(argv[i], "-S")) {
                                if (i + 1 < argc &&
                                    !read_ancestry(argv[i + 1], &sha1_p)) {
-                                       compability = 1;
+                                       compatibility = 1;
                                        i++;
                                        continue;
                                }
@@ -884,7 +884,7 @@ int main(int argc, const char **argv)
                u = c->util;
                get_commit_info(c, &ci);
                fwrite(sha1_to_hex(c->object.sha1), sha1_len, 1, stdout);
-               if(compability) {
+               if(compatibility) {
                        printf("\t(%10s\t%10s\t%d)", ci.author,
                               format_time(ci.author_time, ci.author_tz,
                                           show_raw_time),
index c3af48917c9a96ce86442bea737f4a81c7e0fb55..1e5b846dd3935f54ee8fa1c3620810be059de5d3 100644 (file)
@@ -765,7 +765,7 @@ static int find_header(char *line, unsigned long size, int *hdrsize, struct patc
                        continue;
 
                /*
-                * Make sure we don't find any unconnected patch fragmants.
+                * Make sure we don't find any unconnected patch fragments.
                 * That's a sign that we didn't find a header, and that a
                 * patch has become corrupted/broken up.
                 */
@@ -990,7 +990,7 @@ static int parse_binary(char *buffer, unsigned long size, struct patch *patch)
         * so one line can fit up to 13 groups that would decode
         * to 52 bytes max.  The length byte 'A'-'Z' corresponds
         * to 1-26 bytes, and 'a'-'z' corresponds to 27-52 bytes.
-        * The end of binary is signalled with an empty line.
+        * The end of binary is signaled with an empty line.
         */
        int llen, used;
        struct fragment *fragment;
index 1df531ba28d596a8a8b338cae0c4295fc16892f2..ae901dd25ea4d8d82752db5b28f354fd2eadfb56 100644 (file)
@@ -176,7 +176,7 @@ static int builtin_diff_tree(struct rev_info *revs,
                usage(builtin_diff_usage);
 
        /* We saw two trees, ent[0] and ent[1].
-        * if ent[1] is unintesting, they are swapped
+        * if ent[1] is uninteresting, they are swapped
         */
        if (ent[1].item->flags & UNINTERESTING)
                swap = 1;
index 743ca8c692094a2089de1fbf45cfe65f8acef729..4c2f7dfe03086af3e638f19a541d6c281aba927c 100644 (file)
@@ -941,7 +941,7 @@ int cmd_grep(int argc, const char **argv, char **envp)
         * pattern, but then what follows it must be zero or more
         * valid refs up to the -- (if exists), and then existing
         * paths.  If there is an explicit pattern, then the first
-        * unrecocnized non option is the beginning of the refs list
+        * unrecognized non option is the beginning of the refs list
         * that continues up to the -- (if exists), and then paths.
         */
 
index 7470faa56692e17608d202000b78a91565360b72..335fe5fedcc6523a3b49a3e00686fe381098bcda 100644 (file)
@@ -12,7 +12,7 @@
 static const char git_usage[] =
        "Usage: git [--version] [--exec-path[=GIT_EXEC_PATH]] [--help] COMMAND [ ARGS ]";
 
-/* most gui terms set COLUMNS (although some don't export it) */
+/* most GUI terminals set COLUMNS (although some don't export it) */
 static int term_columns(void)
 {
        char *col_string = getenv("COLUMNS");
index 66b94078229c09d8105fcd7f5800a2cba567c972..a8fac886f1a35dd645a513be70cb6c368f75437d 100644 (file)
@@ -104,7 +104,7 @@ static int get_remotes_uri(const char *repo, const char *uri[MAX_URI])
                        if (n < MAX_URI)
                                uri[n++] = strdup(s);
                        else
-                               error("more than %d URL's specified, ignoreing the rest", MAX_URI);
+                               error("more than %d URL's specified, ignoring the rest", MAX_URI);
                }
                else if (is_refspec && !has_explicit_refspec)
                        add_refspec(strdup(s));
index 875d8252fa72cf7adc1d6bb254ebc3a5995e49dd..5deb81171996029b31da14109c408ffba33f7957 100644 (file)
@@ -129,7 +129,7 @@ int cmd_rm(int argc, const char **argv, char **envp)
         * workspace. If we fail to remove the first one, we
         * abort the "git rm" (but once we've successfully removed
         * any file at all, we'll go ahead and commit to it all:
-        * by then we've already committed ourself and can't fail
+        * by then we've already committed ourselves and can't fail
         * in the middle)
         */
        if (force) {
index caffb926ea49de03c4ced157736626719439a756..1bc1484645b4021ee71415f3b3ed44e4c88030d6 100644 (file)
@@ -320,7 +320,7 @@ static int give_context(struct sline *sline, unsigned long cnt, int num_parent)
        unsigned long i;
 
        /* Two groups of interesting lines may have a short gap of
-        * unintersting lines.  Connect such groups to give them a
+        * uninteresting lines.  Connect such groups to give them a
         * bit of context.
         *
         * We first start from what the interesting() function says,
index bbd26c7b0e80798f1bf4e92b6150bd30c44f3143..6474eab1192fd2f66c810dc49a35b8b99db8ff1f 100644 (file)
@@ -568,7 +568,7 @@ def _translate_newlines(self, data):
         # Windows methods
         #
         def _get_handles(self, stdin, stdout, stderr):
-            """Construct and return tupel with IO objects:
+            """Construct and return tuple with IO objects:
             p2cread, p2cwrite, c2pread, c2pwrite, errread, errwrite
             """
             if stdin == None and stdout == None and stderr == None:
@@ -635,7 +635,7 @@ def _make_inheritable(self, handle):
 
 
         def _find_w9xpopen(self):
-            """Find and return absolut path to w9xpopen.exe"""
+            """Find and return absolute path to w9xpopen.exe"""
             w9xpopen = os.path.join(os.path.dirname(GetModuleFileName(0)),
                                     "w9xpopen.exe")
             if not os.path.exists(w9xpopen):
@@ -812,7 +812,7 @@ def communicate(self, input=None):
         # POSIX methods
         #
         def _get_handles(self, stdin, stdout, stderr):
-            """Construct and return tupel with IO objects:
+            """Construct and return tuple with IO objects:
             p2cread, p2cwrite, c2pread, c2pwrite, errread, errwrite
             """
             p2cread, p2cwrite = None, None
index 5789cfb2654607052f38ce788777520eaccc7bd4..9566a765ef5fc66c80cba02a8868b3e629193b15 100755 (executable)
     }
 }
 
-# colordiff specfic options here.  Need to pre-declare if using variables
+# colordiff specific options here.  Need to pre-declare if using variables
 GetOptions(
     "no-banner" => sub { $show_banner = 0 },
     "plain-text=s" => \&set_color,
index 8b9172aa2ef7402b0a847815bb11a26d1c4444fe..7da9205a5da6a4f016bc6b556bee01895cdcc19d 100644 (file)
@@ -148,7 +148,7 @@ struct delta_index * create_delta_index(const void *buf, unsigned long bufsize)
                return NULL;
 
        /* Determine index hash size.  Note that indexing skips the
-          first byte to allow for optimizing the rabin polynomial
+          first byte to allow for optimizing the Rabin's polynomial
           initialization in create_delta(). */
        entries = (bufsize - 1)  / RABIN_WINDOW;
        hsize = entries / 4;
@@ -205,7 +205,7 @@ struct delta_index * create_delta_index(const void *buf, unsigned long bufsize)
 
        /*
         * Determine a limit on the number of entries in the same hash
-        * bucket.  This guard us against patological data sets causing
+        * bucket.  This guards us against pathological data sets causing
         * really bad hash distribution with most entries in the same hash
         * bucket that would bring us to O(m*n) computing costs (m and n
         * corresponding to reference and target buffer sizes).
@@ -240,7 +240,7 @@ void free_delta_index(struct delta_index *index)
 
 /*
  * The maximum size for any opcode sequence, including the initial header
- * plus rabin window plus biggest copy.
+ * plus Rabin window plus biggest copy.
  */
 #define MAX_OP_SIZE    (5 + 5 + 1 + RABIN_WINDOW + 7)
 
index c16b0c481bb4b7dd3810e7dfbcb21243572f6844..81d13712962dfcf16c4f0f5a574b6950f6c3f154 100644 (file)
@@ -198,8 +198,8 @@ int receive_unpack_pack(int xd[2], const char *me, int quiet, int sideband)
 
 /*
  * A "binary msec" is a power-of-two-msec, aka 1/1024th of a second.
- * Keeing the time in that format means that "bytes / msecs" means
- * is the same as kB/s (modulo rounding).
+ * Keeping the time in that format means that "bytes / msecs" means
+ * the same as kB/s (modulo rounding).
  *
  * 1000512 is a magic number (usecs in a second, rounded up by half
  * of 1024, to make "rounding" come out right ;)
index 679045a540c60e747074a9127bb7003f8a510b1c..db9a20a811199666fb64f34f1e54e0c841f494ee 100755 (executable)
--- a/git-am.sh
+++ b/git-am.sh
@@ -77,7 +77,7 @@ fall_back_3way () {
     # This is not so wrong.  Depending on which base we picked,
     # orig_tree may be wildly different from ours, but his_tree
     # has the same set of wildly different changes in parts the
-    # patch did not touch, so resolve ends up cancelling them,
+    # patch did not touch, so resolve ends up canceling them,
     # saying that we reverted all those changes.
 
     git-merge-resolve $orig_tree -- HEAD $his_tree || {
index e4b09472e1fa27a6431b431572af7353c4f0a9b2..8df2aee4c2d031ac10c66af0a079bd022c281c0d 100755 (executable)
@@ -182,7 +182,7 @@ git-apply --index "$PATCHFILE" || {
        # This is not so wrong.  Depending on which base we picked,
        # orig_tree may be wildly different from ours, but his_tree
        # has the same set of wildly different changes in parts the
-       # patch did not touch, so resolve ends up cancelling them,
+       # patch did not touch, so resolve ends up canceling them,
        # saying that we reverted all those changes.
 
        if git-merge-resolve $orig_tree -- HEAD $his_tree
index 740bc1fd52286dfb486570bf6ea727e9cbaefbfc..ada60ec240a8b3eb4ef6efea6b6223fc8523705f 100755 (executable)
@@ -14,7 +14,7 @@ =head1 Invocation
 
 Imports a project from one or more Arch repositories. It will follow branches
 and repositories within the namespaces defined by the <archive/branch>
-parameters suppplied. If it cannot find the remote branch a merge comes from
+parameters supplied. If it cannot find the remote branch a merge comes from
 it will just import it as a regular commit. If it can find it, it will mark it 
 as a merge whenever possible.
 
@@ -88,7 +88,7 @@ END
 # $arch_branches:
 # values associated with keys:
 #   =1 - Arch version / git 'branch' detected via abrowse on a limit
-#   >1 - Arch version / git 'branch' of an auxilliary branch we've merged
+#   >1 - Arch version / git 'branch' of an auxiliary branch we've merged
 my %arch_branches = map { $_ => 1 } @ARGV;
 
 $ENV{'TMPDIR'} = $opt_t if $opt_t; # $ENV{TMPDIR} will affect tempdir() calls:
@@ -667,7 +667,7 @@ sub apply_cset {
     if (`find $tmp/changeset/patches -type f -name '*.patch'`) {
         # this can be sped up considerably by doing
         #    (find | xargs cat) | patch
-        # but that cna get mucked up by patches
+        # but that can get mucked up by patches
         # with missing trailing newlines or the standard 
         # 'missing newline' flag in the patch - possibly
         # produced with an old/buggy diff.
@@ -1026,7 +1026,7 @@ sub commitid2pset {
 }
 
 
-# an alterative to `command` that allows input to be passed as an array
+# an alternative to `command` that allows input to be passed as an array
 # to work around shell problems with weird characters in arguments
 sub safe_pipe_capture {
     my @output;
index 08d786db2f3ea47503b798dec35d412cd9b22d4f..351d13cb1ef3ad62e410f60e07112afdaaa95094 100755 (executable)
@@ -599,7 +599,7 @@ then
        GIT_AUTHOR_EMAIL=`expr "z$force_author" : '.*\(<.*\)'` &&
        test '' != "$GIT_AUTHOR_NAME" &&
        test '' != "$GIT_AUTHOR_EMAIL" ||
-       die "malformatted --author parameter"
+       die "malformed --author parameter"
        export GIT_AUTHOR_NAME GIT_AUTHOR_EMAIL
 elif test '' != "$use_commit"
 then
index 5dcb2f9a8ecdf43e73ae31bf8ba7dff27acaa367..5d13a54194d23ceaa50bc52a4f192156898d661a 100755 (executable)
 @bfiles = map { chomp } @bfiles;
 foreach my $f (@bfiles) {
     # check that the file in cvs matches the "old" file
-    # extract the file to $tmpdir and comparre with cmp
+    # extract the file to $tmpdir and compare with cmp
     my $tree = safe_pipe_capture('git-rev-parse', "$parent^{tree}");
     chomp $tree;
     my $blob = `git-ls-tree $tree "$f" | cut -f 1 | cut -d ' ' -f 3`;
@@ -273,7 +273,7 @@ sub cleanupcvs {
     }
 }
 
-# An alterative to `command` that allows input to be passed as an array
+# An alternative to `command` that allows input to be passed as an array
 # to work around shell problems with weird characters in arguments
 # if the exec returns non-zero we die
 sub safe_pipe_capture {
index 69aef3c20b099edd32aaa76ad8cfceb7e3f8a53a..63b18b99f65fe7ac60a76a0dfd2662d7400696c8 100755 (executable)
@@ -25,7 +25,7 @@ conf=$GIT_DIR/gitweb/httpd.conf
 
 # Defaults:
 
-# if installed, it doens't need further configuration (module_path)
+# if installed, it doesn't need further configuration (module_path)
 test -z "$httpd" && httpd='lighttpd -f'
 
 # probably the most popular browser among gitweb users
index 5619409f1c7ee9c694c2de59aff195f971502226..fba4b0cb5fffbb1ad3f39c670c6364975c52186a 100755 (executable)
@@ -8,7 +8,7 @@
 #   $2 - file in branch1 SHA1 (or empty)
 #   $3 - file in branch2 SHA1 (or empty)
 #   $4 - pathname in repository
-#   $5 - orignal file mode (or empty)
+#   $5 - original file mode (or empty)
 #   $6 - file in branch1 mode (or empty)
 #   $7 - file in branch2 mode (or empty)
 #
index ce8a31fda050f36b24b8dffa5ee29e7dde074963..4039435ce4a938fdf9cae4eaa74303d5cc7527d0 100755 (executable)
@@ -47,7 +47,7 @@ def setupIndex(temporary):
 
 def merge(h1, h2, branch1Name, branch2Name, graph, callDepth=0, ancestor=None):
     '''Merge the commits h1 and h2, return the resulting virtual
-    commit object and a flag indicating the cleaness of the merge.'''
+    commit object and a flag indicating the cleanness of the merge.'''
     assert(isinstance(h1, Commit) and isinstance(h2, Commit))
 
     global outputIndent
index f10cadbf159bcd63af0c3834bd7cd2fab6cce57c..21775fc21ae6668b04972ef942b2d90a789f4af6 100755 (executable)
@@ -63,7 +63,7 @@ esac
 shift ;# away the initial 'x'
 
 # $# is now 0 if there was no explicit refspec on the command line
-# and there was no defalt refspec to push from remotes/ file.
+# and there was no default refspec to push from remotes/ file.
 # we will let git-send-pack to do its "matching refs" thing.
 
 case "$remote" in
index 86b51abd21748c19235a703b1b523525d05383cd..364baff80645efb225e433dbf5845e678df60760 100755 (executable)
@@ -49,7 +49,7 @@ if [ -n "$quilt_author" ] ; then
        quilt_author_email=$(expr "z$quilt_author" : '.*<\([^>]*\)') &&
        test '' != "$quilt_author_name" &&
        test '' != "$quilt_author_email" ||
-       die "malformatted --author parameter"
+       die "malformed --author parameter"
 fi
 
 # Quilt patch directory
index c9c1975b7f7dd25ef8d5e3dd475b56cb624592bd..d7f5dce48966ebb688d981ae5f2b09f05839c2e4 100755 (executable)
@@ -361,7 +361,7 @@ sub expand_aliases {
    --smtp-server  If set, specifies the outgoing SMTP server to use.
                   Defaults to localhost.
 
-  --suppress-from Supress sending emails to yourself if your address
+  --suppress-from Suppress sending emails to yourself if your address
                   appears in a From: line.
 
    --quiet     Make git-send-email less verbose.  One line per email should be
index f04e26993956a2264a9bf5d67c0cbd9c46c1bee6..4530ffe42c66713f1dc9e79b3ad62124338405de 100755 (executable)
@@ -2429,7 +2429,7 @@ sub extract_metadata {
                                                        \s([a-f\d\-]+)$/x);
        if (!$rev || !$uuid || !$url) {
                # some of the original repositories I made had
-               # indentifiers like this:
+               # identifiers like this:
                ($rev, $uuid) = ($id =~/^git-svn-id:\s(\d+)\@([a-f\d\-]+)/);
        }
        return ($url, $rev, $uuid);
index 6a23f2d8a2d87c46ac9e1ec7bcb36e540967f93b..083d067e17f6bfbdbd936b0fbe3683ac4f1f7b5b 100644 (file)
@@ -5,7 +5,7 @@
 #include "refs.h"
 
 static const char name_rev_usage[] =
-       "git-name-rev [--tags] ( --all | --stdin | commitish [commitish...] )\n";
+       "git-name-rev [--tags] ( --all | --stdin | committish [committish...] )\n";
 
 typedef struct rev_name {
        const char *tip_name;
index b486ea528afed6acb19955fdfae770ec6037ff3f..04a48b925b4db0e302650f7383b5ccbb948665de 100644 (file)
@@ -28,7 +28,7 @@ struct object_entry {
        struct object_entry *delta;     /* delta base object */
        struct packed_git *in_pack;     /* already in pack */
        unsigned int in_pack_offset;
-       struct object_entry *delta_child; /* delitified objects who bases me */
+       struct object_entry *delta_child; /* deltified objects who bases me */
        struct object_entry *delta_sibling; /* other deltified objects who
                                             * uses the same base as me
                                             */
@@ -39,7 +39,7 @@ struct object_entry {
 };
 
 /*
- * Objects we are going to pack are colected in objects array (dynamically
+ * Objects we are going to pack are collected in objects array (dynamically
  * expanded).  nr_objects & nr_alloc controls this array.  They are stored
  * in the order we see -- typically rev-list --objects order that gives us
  * nice "minimum seek" order.
index f591d98b3f9b74590e38c7daecb797bb844695f6..140cb53370fb23eb56b1872a2f328a0840e2820f 100644 (file)
@@ -62,7 +62,7 @@
  * computation of W[t+4].
  *
  * The first 16 rounds use W values loaded directly from memory, while the
- * remianing 64 use values computed from those first 16.  We preload
+ * remaining 64 use values computed from those first 16.  We preload
  * 4 values before starting, so there are three kinds of rounds:
  * - The first 12 (all f0) also load the W values from memory.
  * - The next 64 compute W(i+4) in parallel. 8*f0, 20*f1, 20*f2, 16*f1.
index bc3580844023c9ae0f833ea5799c05887e1d88aa..f7bb3a1c54c001a83dd0c2ee9c2b59dd686a66d1 100644 (file)
@@ -1660,7 +1660,7 @@ int has_sha1_file(const unsigned char *sha1)
 
 /*
  * reads from fd as long as possible into a supplied buffer of size bytes.
* If neccessary the buffer's size is increased using realloc()
  *
  * returns 0 if anything went fine and -1 otherwise
  *
index 916ee15ba1ed840fbd0df9d91e4f06fae8fde357..dd9caad1c2a34a6721aafa1840916a5a7471ece8 100755 (executable)
@@ -31,7 +31,7 @@ test_expect_success 'cloning with reference' \
 
 cd "$base_dir"
 
-test_expect_success 'existance of info/alternates' \
+test_expect_success 'existence of info/alternates' \
 'test `wc -l <C/.git/objects/info/alternates` = 2'
 
 cd "$base_dir"
index 097d037f5da5aad41872952533bdaef0b1e50d3c..2e1b48a89b1c8a33c62be530bd40fa4d57eb2836 100755 (executable)
@@ -81,7 +81,7 @@ test_valid_repo"
 
 cd "$base_dir"
 
-test_expect_failure 'that info/alternates is neccessary' \
+test_expect_failure 'that info/alternates is necessary' \
 'cd C &&
 rm .git/objects/info/alternates &&
 test_valid_repo'
index 693de9b32dea04140d58ba98d0db07ac0e724a6b..7831e3461c3dd7d332db56e9f5828a27009c9460 100755 (executable)
@@ -154,7 +154,7 @@ test_sequence()
        test_bisection_diff 0 $_bisect_option u5 ^U
        
 #
-# the following illustrate's Linus' binary bug blatt idea. 
+# the following illustrates Linus' binary bug blatt idea.
 #
 # assume the bug is actually at l3, but you don't know that - all you know is that l3 is broken
 # and it wasn't broken before
index 262381379f247a74f1656cfdd7f9b0c6d386d372..8f7366da8d53feb95d08fd57c04b96c7bcbb9625 100755 (executable)
@@ -4,7 +4,7 @@
 #
 
 # See http://marc.theaimsgroup.com/?l=git&m=111463358500362&w=2 for a
-# nice decription of what this is about.
+# nice description of what this is about.
 
 
 test_description='Test criss-cross merge'
index ed7ad2041c6f81df8b0191374c5b0e4e91683a70..d76e76a0e6d987cdec985e304ad682020fef5e1f 100644 (file)
@@ -84,7 +84,7 @@ static long xdl_split(unsigned long const *ha1, long off1, long lim1,
                 * We need to extent the diagonal "domain" by one. If the next
                 * values exits the box boundaries we need to change it in the
                 * opposite direction because (max - min) must be a power of two.
-                * Also we initialize the extenal K value to -1 so that we can
+                * Also we initialize the external K value to -1 so that we can
                 * avoid extra conditions check inside the core loop.
                 */
                if (fmin > dmin)
@@ -119,7 +119,7 @@ static long xdl_split(unsigned long const *ha1, long off1, long lim1,
                 * We need to extent the diagonal "domain" by one. If the next
                 * values exits the box boundaries we need to change it in the
                 * opposite direction because (max - min) must be a power of two.
-                * Also we initialize the extenal K value to -1 so that we can
+                * Also we initialize the external K value to -1 so that we can
                 * avoid extra conditions check inside the core loop.
                 */
                if (bmin > dmin)
@@ -405,7 +405,7 @@ static int xdl_change_compact(xdfile_t *xdf, xdfile_t *xdfo, long flags) {
        /*
         * This is the same of what GNU diff does. Move back and forward
         * change groups for a consistent and pretty diff output. This also
-        * helps in finding joineable change groups and reduce the diff size.
+        * helps in finding joinable change groups and reduce the diff size.
         */
        for (ix = ixo = 0;;) {
                /*
@@ -1660,7 +1660,7 @@ int has_sha1_file(const unsigned char *sha1)
 /*
  * reads from fd as long as possible into a supplied buffer of size bytes.
- * If neccessary the buffer's size is increased using realloc()
+ * If necessary the buffer's size is increased using realloc()
  *
  * returns 0 if anything went fine and -1 otherwise